Ref

Struct Ref 

pub struct Ref<'a, K, V, H, A: Allocator> { /* private fields */ }
A reference to an atomic cell in a LeapMap, which cannot mutate the referenced cell value.

Implementations

Source

impl<'a, K, V, H, A> Ref<'a, K, V, H, A>
where A: Allocator, V: Value,

pub fn new( map: &'a LeapMap<K, V, H, A>, cell: &'a AtomicCell<K, V>, hash: u64, ) -> Ref<'a, K, V, H, A>

Creates a new ref type referencing the specified cell and map.

pub fn key(&mut self) -> Option<K>
where K: Eq + Hash + Copy, H: BuildHasher + Default,

Loads the key for the referenced cell.

This requires &mut self since it’s possible that the underlying data for the map has been migrated, and that therefore the referenced cell is out of date, and returning the current value will be incorrect. In such a case, the cell needs to be updated to reference the correct cell, hence mut self. This ensures that the returned value is always the most up to date value.

It is also possible that the cell has been deleted, in which case the returned value will be None

pub fn value(&mut self) -> Option<V>
where K: Eq + Hash + Copy, H: BuildHasher + Default,

Loads the value for the referenced cell.

This requires &mut self since it’s possible that the underlying data for the map has been migrated, and that therefore the referenced cell is out of date, and returning the current value will be incorrect. In such a case, the cell needs to be updated to reference the correct cell, hence mut self. This ensures that the returned value is always the most up to date value.

It is also possible that the cell has been deleted, in which case the returned value will be None

pub fn key_value(&mut self) -> Option<(K, V)>
where K: Eq + Hash + Copy, H: BuildHasher + Default,

Loads the key-value pair for the referenced cell.

This requires &mut self since it’s possible that the underlying data for the map has been migrated, and that therefore the referenced cell is out of date, and returning the current value will be incorrect. In such a case, the cell needs to be updated to reference the correct cell, hence mut self. This ensures that the returned value is always the most up to date value.

It is also possible that the cell has been deleted, in which case the returned value will be None.